==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/vpclattice/kotlin/inputs/TargetGroupConfigHealthCheckMatcherArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.vpclattice.kotlin.inputs

import com.pulumi.aws.vpclattice.inputs.TargetGroupConfigHealthCheckMatcherArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property value The HTTP codes to use when checking for a successful response from a target.
 */
public data class TargetGroupConfigHealthCheckMatcherArgs(
    public val `value`: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.vpclattice.inputs.TargetGroupConfigHealthCheckMatcherArgs> {
    override fun toJava(): com.pulumi.aws.vpclattice.inputs.TargetGroupConfigHealthCheckMatcherArgs =
        com.pulumi.aws.vpclattice.inputs.TargetGroupConfigHealthCheckMatcherArgs.builder()
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TargetGroupConfigHealthCheckMatcherArgs].
 */
@PulumiTagMarker
public class TargetGroupConfigHealthCheckMatcherArgsBuilder internal constructor() {
    private var `value`: Output<String>? = null

    /**
     * @param value The HTTP codes to use when checking for a successful response from a target.
     */
    @JvmName("gcaqutwoqahfjprr")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The HTTP codes to use when checking for a successful response from a target.
     */
    @JvmName("pbhepljinfefxpgr")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): TargetGroupConfigHealthCheckMatcherArgs =
        TargetGroupConfigHealthCheckMatcherArgs(
            `value` = `value`,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/vpclattice/kotlin/inputs/TargetGroupConfigHealthCheckMatcherArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.vpclattice.kotlin.inputs

import com.pulumi.aws.vpclattice.inputs.TargetGroupConfigHealthCheckMatcherArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property value The HTTP codes to use when checking for a successful response from a target.
 */
public data class TargetGroupConfigHealthCheckMatcherArgs(
    public val `value`: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.vpclattice.inputs.TargetGroupConfigHealthCheckMatcherArgs> {
    override fun toJava(): com.pulumi.aws.vpclattice.inputs.TargetGroupConfigHealthCheckMatcherArgs =
        com.pulumi.aws.vpclattice.inputs.TargetGroupConfigHealthCheckMatcherArgs.builder()
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TargetGroupConfigHealthCheckMatcherArgs].
 */
@PulumiTagMarker
public class TargetGroupConfigHealthCheckMatcherArgsBuilder internal constructor() {
    private var `value`: Output<String>? = null

    /**
     * @param value The HTTP codes to use when checking for a successful response from a target.
     */
    @JvmName("soauxglejgqqdiox")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The HTTP codes to use when checking for a successful response from a target.
     */
    @JvmName("pugaqqixedeiampk")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): TargetGroupConfigHealthCheckMatcherArgs =
        TargetGroupConfigHealthCheckMatcherArgs(
            `value` = `value`,
        )
}
